#### File structure

```bash
./
├── README.md
├── csvfiles
│   ├── filtered
│   │   ├── TMCs-C02-stddev-flag-diagnostics.csv
│   │   ├── TMCs-no-all-diagnostics.csv
│   │   └── TMCs-perturbativeT-flag-diagnostics.csv
│   └── used
│       ├── TMCs-delta-aIP.csv
│       ├── TMCs-delta-sse.csv
│       └── TMCs-diagnostics.csv
├── models
│   ├── aIP
│   │   ├── aIP-del-aIP-CCSD-all-with_aIP-1.h5
│   │   ├── aIP-del-aIP-CCSD-dft-with_aIP-1.h5
│   │   ├── aIP-del-aIP-CCSD-mp2-with_aIP-1.h5
│   │   ├── aIP-del-aIP-b3lyp-all-with_aIP-1.h5
│   │   ├── aIP-del-aIP-b3lyp-dft-with_aIP-1.h5
│   │   └── aIP-del-aIP-b3lyp-mp2-with_aIP-1.h5
│   ├── diagnostics
│   │   ├── diagnostic-%CorrE_orca-dft.h5
│   │   ├── diagnostic-C0^2_orb_14-dft.h5
│   │   ├── diagnostic-T1-dft.h5
│   │   ├── diagnostic-TAE-dft.h5
│   │   ├── diagnostic-largest_amp-dft.h5
│   │   ├── diagnostic-nHOMO_MP2-dft.h5
│   │   ├── diagnostic-nHOMO_orb_14-dft.h5
│   │   ├── diagnostic-nLUMO_MP2-dft.h5
│   │   └── diagnostic-nLUMO_orb_14-dft.h5
│   └── sse
│       ├── sse-del-sse-CCSD-all-with_sse-1.h5
│       ├── sse-del-sse-CCSD-dft-with_sse-1.h5
│       ├── sse-del-sse-CCSD-mp2-with_sse-1.h5
│       ├── sse-del-sse-b3lyp-all-with_sse-1.h5
│       ├── sse-del-sse-b3lyp-dft-with_sse-1.h5
│       └── sse-del-sse-b3lyp-mp2-with_sse-1.h5
└── optgeos
    ├── all-he.zip
    ├── ax1.zip
    ├── ax2-cis.zip
    └── ax2-trans.zip
```

***

#### csvfiles

All csv files contain columns that identify a TMC (metal, oxidation state, spin state, ligand symmetry, ligands, metal-He distances, etc.), the properties of interest, and input features (i.e., CD-RACs).

##### filtered

Transition metal complexes that were removed from the final data set for various reasons:

* Not all 14 MR diagnostics were successfully obtained: `TMCs-no-all-diagnostics.csv`
* With abnormally large perturbative T corrections: `TMCs-perturbativeT-flag-diagnostics.csv`
* With a std. dev. > 0.1 for the C0^2 diagnostics obtained by 10, 12, and 14 active orbitals:  `TMCs-C02-stddev-flag-diagnostics.csv`

##### used

Final data sets that are used in the work to get productive results:

* All 14 MR diagnostics for each TMC: `TMCs-diagnostics.csv`
* The difference of adiabatic spin-splitting energy (delta.sse) between a lower-level method (such as HF, B3LYP, CCSD) and CCSD(T) for all TMCs in the final set: `TMCs-delta-sse.csv`. Note that we have `sse.<method> (kcal/mol)` column that shows the adiabatic spin splitting energy of a method named `<method>`. We also have `delta.sse.<method> (kcal/mol)` column that shows the difference of adiabatic spin splitting energy between a method named `<method>` and CCSD(T).
* The difference of adiabatic ionization potential (delta-aIP) between a lower-level method  (such as HF, B3LYP, CCSD) and CCSD(T) for all TMCs in the final set: `TMCs-delta-aIP.csv`. Note that we have `aIP.<method> (eV)` column that shows the adiabatic spin splitting energy of a method named `<method>`. We also have `delta.aIP.<method> (eV)` column that shows the difference of adiabatic ionization potential between a method named `<method>` and CCSD(T).

***

#### models

Models are available on Zenodo https://zenodo.org/record/5851432#.YeHOoS-B1pQ.

All models are .h5 files as `keras.model` object, which can be loaded by the following

```python
import keras
model = keras.models.load_model(<model-path>, compile=False)
model.compile(loss="mse",
              optimizer=tf.keras.optimizers.Adam(learning_rate=1e-3,
                                                 beta_1=0.95,
                                                 beta_2=0.999,
                                                 decay=0,
                                                 amsgrad=True,
                                                 ),
              metrics=["mae"]
              )
```

##### diagnostic

Models that predict the WFT-diagnostics from DFT-based diagnostics and CD-RACs. Naming format: `diagnostic-<diagnostic name>_dft.json`.

##### sse

Models that predict the difference of adiabatic spin-splitting energy (delta-sse) between a lower-level method (such as B3LYP and CCSD) and CCSD(T). Naming format: `sse-del-sse-<low-level method>-<highest level of theory as inputs>-with_sse-1.h5`

##### aIP

Models that predict the difference of adiabatic ionization potential (delta-aIP) between a lower-level method (such as B3LYP and CCSD) and CCSD(T). Naming format: `aIP-del-aIP-<low-level method>-<highest level of theory as inputs>-with_aIP-1.h5`

***

#### optgeos

All DFT optimized geometries (with metal-He distances constrained) are grouped by their ligand symmetry types: `all-he.zip` contains complexes with all six ligands as He atoms; `ax1.zip` contains complexes with 1 axial ligand as non-He ligand; `ax2-trans.zip` contains complexes with 2 axial ligands as non-He ligands and thus are of trans geometry; `ax2-cis.zip` contains complexes with 1 axial and 1 equatorial ligand as non-He ligands and thus are of cis geometry;

